recordStore.RemoteSlaveRecordStore

|  | ## Cheshire3 Object Model: Class RemoteSlaveRecordStore

Module recordStore :: Class RemoteSlaveRecordStore

## Class RemoteSlaveRecordStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
          baseObjects.RecordStore --+
                                    |
                    SimpleRecordStore --+
                                        |
                                       RemoteSlaveRecordStore

Instance Methods

__init__(self, session, config, parent)
begin_storing(self, session, wt=None)
create_record(self, session, record=None)
store_record(self, session, record)
fetch_record(self, session, record)
Inherited from `SimpleRecordStore`: `delete_record`, `fetch_recordChecksum`, `fetch_recordSize`, `process_data`, `replace_record` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

recordStore |
writeTask |
taskType |
protocol |
Inherited from `SimpleRecordStore`: `idNormalizer`, `inTransformer`, `outParser` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
Overrides: SimpleRecordStore.__init__

### begin_storing(self, session, wt=None) | source code

### create_record(self, session, record=None) | source code
Overrides: SimpleRecordStore.create_record

### store_record(self, session, record) | source code
Overrides: SimpleRecordStore.store_record

### fetch_record(self, session, record) | source code
Overrides: SimpleRecordStore.fetch_record

Class Variable Details

    ### recordStore Value:
        ''

    ### writeTask Value:
        None

    ### taskType Value:
        None

    ### protocol Value:
        ''